@@ -10,7 +10,7 @@ use POSIX qw(_exit :sys_wait_h);
 
 use namespace::clean -except => 'meta';
 
-with qw(KiokuDB::Test::Fixture);
+with qw(KiokuDB::Test::Fixture) => { excludes => [qw/run required_backend_roles/] };
 
 use constant required_backend_roles => qw(Clear TXN Concurrency::POSIX);
 
